var express = require('express');
var router = express.Router();
var Merchant = require('../utils/sdk/adapay-sdk/merchant/Merchant')
const {resolve} = require('path')
 
/**
 *  商户入驻以及支付渠道批量配置
 * @param {Object} kwargs 
 * 参数说明
    请求ID	request_id	变长32位String	Y	 
    渠道配置的商户	sub_api_key	变长512为String	Y	 
    渠道号	bank_channel_no	变长128位String	Y	pnrpay渠道号(暂由运营提供)
    费率	fee_type	定长2位String	Y	
    01-标准费率线上,02-标准费率线下

    商户号下的应用id	app_id	变长40位String	Y	Adapay平台的app_id
    微信经营类目	wx_category	变长128位String	Y	微信经营类目表（与支付宝两者最少选一个）（见编码表中微信经营类目表）
    支付宝经营类目	alipay_category	变长128位String	Y	支付宝经营类目表（与微信两者最少选一个）（见编码表中支付表经营类目表）
    行业分类	cls_id	变长10位String	N	支付宝必填，行业分类（见编码表中支付表经营类目表）
    入驻模式	model_type	定长1位String	N	1-服务商模式
    商户种类	mer_type	定长1位String	N	
    1-政府机构,2-国营企业,3-私营企业,4-外资企业,5-个体工商户,7-事业单位

    省份编码	province_code	变长16位String	Y	见编码表中城市编码表
    城市编码	city_code	变长16位String	Y	见编码表中城市编码表
    区县编码	district_code	变长16位String	Y	见编码表中城市编码表
    配置值	add_value_list	变长1024位String	Y	
    形式为 {'支付渠道代码':{'支付渠道参数1':'值1'，'支付渠道参数2':'值2'}}

    为商户开通传递过来的支付渠道，如果支付渠道没有额外参数，传空字符串即可，

    举例：{

        "wx_lite":{"appid":"xxx"},

        "wx_pub":{"appid":"xxxx","path":"http://xxxx"},

        "wx_scan":"",

        "alipay":"",

        "alipay_wap":"",

        "alipay_lite":"",

        "alipay_qr":"",

        "alipay_scan":""

    }

    (支付渠道id见编码表中的支付渠道列表)

 */
router.post('/merConf', async function(req, res, next) {
    try {
        let { env, prod_mode, merchantNO,
            request_id, sub_api_key, bank_channel_no, fee_type, wx_category, app_id, 
            alipay_category, cls_id, model_type, mer_type, province_code, 
            city_code, district_code, add_value_list
        } = req.body

        Merchant.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Merchant.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Merchant.Config.config_dirname = resolve('./utils/config_test')
            Merchant.Config.base_url = "https://api-test.adapay.tech"
        }
        // Merchant.set_merchant_path(configFilePath)
        Merchant.set_group_merchant_path(merchantNO || "yifuyun")

        let result = await Merchant.BatchInput.merConf({
            request_id, sub_api_key, bank_channel_no, fee_type, wx_category, app_id, 
            alipay_category, cls_id, model_type, mer_type, province_code, 
            city_code, district_code, add_value_list
        })
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});


/**
 *  入驻以及支付渠道批量配置结果查询
 * @param {Object} kwargs 
 * 参数说明
    请求ID	request_id	变长32位String	Y	入驻以及支付渠道批量配置接口使用的request_id

 */
router.post('/queryMerConf', async function(req, res, next) {
    try {
        let { env, prod_mode, merchantNO, app_id, 
            request_id,
        } = req.body

        Merchant.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Merchant.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Merchant.Config.config_dirname = resolve('./utils/config_test')
            Merchant.Config.base_url = "https://api-test.adapay.tech"
        }
        // Merchant.set_merchant_path(configFilePath)
        Merchant.set_group_merchant_path(merchantNO || "yifuyun")

        let result = await Merchant.BatchInput.queryMerConf({
            request_id
        })
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});


/**
 *  商户入驻修改
 * @param {Object} kwargs 
 * 参数说明
    请求ID	request_id	变长32位String	Y	 
    渠道配置的商户	sub_api_key	变长512为String	Y	 
    支付宝入驻修改参数信息	alipay_request_params	变长String	N	
    json字符串，如需修改支付宝入驻信息，请传入此参数，

    具体示例如下：

    {
        "mer_short_name": "天气科技",
        "mer_phone": "15866666666",
        "fee_type": "01",
        "card_no": "6227000734730752277",
        "card_name": "上海天气科技有限公司",
        "category": "2015050700000000",
        "cls_id": "5812",
        "mer_name": "上海天气科技有限公司",
        "mer_addr": "上海市浦东新区",
        "contact_name": "王先生",
        "contact_phone": "15866666666",
        "contact_mobile": "15866666666",
        "contact_email": "wang@163.com",
        "legal_id_no": "310555555555555555",
        "mer_license": "110108001111111",
        "province_code": "310000",
        "city_code": "310100",
        "district_code": "310115"
    }

    微信入驻修改参数信息	wx_request_params	变长String	N	
    json字符串，如需修改微信入驻信息，请传入此参数，

    具体示例如下：

    {
        "mer_short_name": "天气科技",
        "mer_phone": "15866666666"
    }

    alipay_request_params内容如下

    参数中文名称	参数名称	数据格式	是否必输	说明
    商户简称	mer_short_name	String(10)	N	
    alipay_request_params二级参数：

    商户简称，长度为10个中文

    商户电话	mer_phone	String(11)	N	
    alipay_request_params二级参数：

    商户客服电话

    费率类型	fee_type	Sting(2)	N	
    alipay_request_params二级参数：

    费率类型：01-线上、02-线下

    结算卡号	card_no	String(32)	N	
    alipay_request_params二级参数：

    结算卡号

    结算卡户名	card_name	String(64)	N	
    alipay_request_params二级参数：

    结算卡户名

    经营类目	category	String(128)	N	
    alipay_request_params二级参数：

    支付宝：支付宝经营类目表

    行业分类	cls_id	String(10)	N	
    alipay_request_params二级参数：

    支付宝必填，行业分类

    商户名	mer_name	String(32)	N	
    alipay_request_params二级参数：

    商户名称

    商户地址	mer_addr	String(128)	N	
    alipay_request_params二级参数：

    商户地址

    联系人姓名	contact_name	String(32)	N	alipay_request_params二级参数：
    联系人电话	contact_phone	String(11)	N	
    alipay_request_params二级参数：

    联系人手机号

    联系人手机	contact_mobile	String(11)	N	
    alipay_request_params二级参数：

    联系人手机号

    联系人邮箱	contact_email	String(128)	N	
    alipay_request_params二级参数：

    联系人邮箱

    法人身份证号	legal_id_no	String(32)	N	alipay_request_params二级参数：
    商户营业执照编号	mer_license	String(32)	N	alipay_request_params二级参数：
    省份编码	province_code	String(16)	N	
    alipay_request_params二级参数：

    见城市编码表

    城市编码	city_code	String(16)	N	
    alipay_request_params二级参数：

    见城市编码表

    区县编码	district_code	String(16)	N	
    alipay_request_params二级参数：

    见城市编码表

    wx_request_params内容如下

    参数中文名称	参数名称	数据格式	是否必输	说明
    商户简称	mer_short_name	String(10)	N	
    wx_request_params二级参数：

    商户简称，长度为10个中文

    商户电话	mer_phone	String(11)	N	
    wx_request_params二级参数：

    商户客服电话

 */
router.post('/merResidentModify', async function(req, res, next) {
    try {
        let { env, prod_mode, merchantNO, app_id, 
            request_id, sub_api_key, alipay_request_params, wx_request_params
        } = req.body

        Merchant.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Merchant.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Merchant.Config.config_dirname = resolve('./utils/config_test')
            Merchant.Config.base_url = "https://api-test.adapay.tech"
        }
        // Merchant.set_merchant_path(configFilePath)
        Merchant.set_group_merchant_path(merchantNO || "yifuyun")

        let result = await Merchant.BatchInput.merResidentModify({
            request_id, sub_api_key, alipay_request_params, wx_request_params
        })
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});

module.exports = router;
