var express = require('express');
var router = express.Router();
var Merchant = require('../utils/sdk/adapay-sdk/merchant/Merchant')
const {resolve} = require('path')
var multipart = require('connect-multiparty');
var multipartMiddleware = multipart();

/**
 *  代理商（渠道商）上送商户证照接口
 * @param {Object} kwargs 
 * 参数说明
    商户子apiKey	subApiKey	变长64位String	Y	商户的子apiKey
    图片内容	file	Mutipart	Y	图片必须JPG/PNG/JPEG/BMP等类型的文件，大小在2M以内
    图片内容标记	fileType	String	Y	01->三证合一码，02->法人身份证正面，03->法人身份证反面，04->门店，05->开户许可证，06->股东身份证正面，07->股东身份证反面
 */
router.post('/merProfilePicture', multipartMiddleware, async function(req, res, next) {
    try {
        let { env, prod_mode, app_id, merchantNO,
            subApiKey, fileType
        } = req.body

        Merchant.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Merchant.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Merchant.Config.config_dirname = resolve('./utils/config_test')
            Merchant.Config.base_url = "https://api-test.adapay.tech"
        }
        // Merchant.set_merchant_path(configFilePath)
        Merchant.set_group_merchant_path(merchantNO || "yifuyun")

        // 文件处理
        let {file} = req.files

        let result = await Merchant.MerProfile.merProfilePicture({
            subApiKey, fileType
        }, file.path)
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});


/**
 *  代理商（渠道商）将商户证照信息提交审核接口
 * @param {Object} kwargs 
 * 参数说明
    
    商户子apiKey	subApiKey	String	Y	商户子apiKey
    统一社会信用代码图片ID	socialCreditCodeId	String	Y	 
    法人身份证正面图片ID	legalCertIdFrontId	String	Y	 
    法人身份证反面图片ID	legalCertIdBackId	String	Y	 
    线上业务网址或者商城地址	businessAdd	String	N	如果商户业务类型包含线上，线上业务网址必传
    门店图片ID	storeId	String	N	
    如果商户业务类型包含线下，门店图片ID必传；

    门店照片的多个ID用竖线连接

    开户许可证图片ID	accountOpeningPermitId	String	N	 
    股东信息	shareholderInfoList	JSON List	N	
    JSON数组字符串结构见下面例子，如果上送股东数据，

    JSON的各个KEY的数据都不能为空

    shareholderInfoList 字段说明：

    参数中文名称	参数名称	数据格式	是否必须	说明
    身份证背面图片id	certBackImageId	String	必须	adapay生成的身份证背面图片id
    身份证正面图片id	certFrontImageId	String	必须	adapay生成的身份证正面图片id
    身份证号码	certId	String	必须	身份证号码
    身份证姓名	certName	String	必须	身份证姓名
 */
router.post('/merProfileForAudit', async function(req, res, next) {
    try {
        let { env, prod_mode, merchantNO,
            subApiKey, socialCreditCodeId, legalCertIdFrontId, legalCertIdBackId, businessAdd,
            storeId, accountOpeningPermitId, shareholderInfoList
        } = req.body

        Merchant.Config.prod_mode = prod_mode
        
        let configFilePath = ''
        if (parseInt(env) === 1) { // 生产环境
            // configFilePath = resolve('./utils/merchantConfig.json')
            Merchant.Config.config_dirname = resolve('./utils/config_release')
        }else{
            // configFilePath = resolve('./utils/merchantConfigTest.json')
            Merchant.Config.config_dirname = resolve('./utils/config_test')
            Merchant.Config.base_url = "https://api-test.adapay.tech"
        }
        // Merchant.set_merchant_path(configFilePath)
        Merchant.set_group_merchant_path(merchantNO || "yifuyun")

        let result = await Merchant.MerProfile.merProfileForAudit({
            subApiKey, socialCreditCodeId, legalCertIdFrontId, legalCertIdBackId, businessAdd,
            storeId, accountOpeningPermitId, shareholderInfoList
        })
        res.json({
            message: "请求成功",
            data: result,
            code: 0
        })
    } catch (error) {
        res.json({
            message: error.toString(),
            code: -1
        })
    }
});

module.exports = router;
